iced_multi_windowTrait Window
Source pub trait Window<App, Theme, Message, Renderer = Renderer>:
Send
+ Debug
+ DynClone {
// Required methods
fn view<'a>(&'a self, app: &'a App) -> Element<'a, Message, Theme, Renderer>;
fn title(&self, app: &App) -> String;
fn theme(&self, app: &App) -> Theme;
fn settings(&self) -> Settings;
fn id(&self) -> String;
fn class(&self) -> &'static str;
}
The unique identifier for this window. This is used for the comparison of windows, so it is recommended to include any internal data in the id.
An identifier for this window’s “class”. Whereas id is used to identify individual windows, class is used to identify a window’s type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
The unique identifier for this window. This is used for the comparison of windows, so it is recommended to include any internal data in the id.
An identifier for this window’s “class”. Whereas id is used to identify individual windows, class is used to identify a window’s type.